# --- Environment variables
ENV_CONFIG_FOLDER = "CONFIG_FOLDER"
ENV_CONFIG_PROJECT_NAME = "CONFIG_PROJECT_NAME"
ENV_CONFIG_FILE_EXTENSION = "CONFIG_FILE_EXTENSION"
ENV_CONFIG_ENVIRONMENT = "CONFIG_ENVIRONMENT"

# --- File extension
FILE_EXT_YAML = ".yaml"
FILE_EXT_YML = ".yml"
FILE_EXT_JSON = ".json"

# --- Default values
DEFAULT_CONFIG_FOLDER = "./app/resources"
DEFAULT_CONFIG_PROJECT_NAME = "application"
DEFAULT_CONFIG_FILE_EXTENSION = FILE_EXT_YAML
